/*! Copyright [Amazon.com](http://amazon.com/), Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: Apache-2.0 */
import { NodePackageManager, NodeProject } from "projen/lib/javascript";
/**
 * Utility functions for working with different Node package managers.
 * @experimental
 */
export declare namespace NodePackageUtils {
    /**
     * Remove the "projen" script from package.json scripts, which causes recursive projen execution
     * for other scripts in format of "yarn projen [command]".
     * @param project NodeProject to remove "projen" script
     * @see https://github.com/projen/projen/blob/37983be94b37ee839ef3337a1b24b014a6c29f4f/src/javascript/node-project.ts#L512
     */
    function removeProjenScript(project: NodeProject): void;
    /**
     * Command based utilities
     */
    namespace command {
        /**
         * Get command to run a script defined in the package.json
         */
        function runScript(packageManager: NodePackageManager, ...args: string[]): string;
        /**
         * Get command to execute projen or a projen task
         */
        function projen(packageManager: NodePackageManager, ...args: string[]): string;
        /**
         * Get command to execute a shell command
         */
        function exec(packageManager: NodePackageManager, ...args: string[]): string;
        /**
         * Get command to run a package in a temporary environment
         */
        function downloadExec(packageManager: NodePackageManager, ...args: string[]): string;
        /**
         * Get bash command for executing an executable in the package manager /bin dir.
         * Example: `$(yarn bin)/${cmd}`
         */
        function bin(packageManager: NodePackageManager, cmd: string): string;
    }
}
